FlattenKeyStyle enum
How nested JSON paths are turned into a single lookup key at codegen time.
- Inheritance
- Available extensions
Values
- dot → const FlattenKeyStyle
-
Nested:
profile.title— flat keys unchanged. - camel → const FlattenKeyStyle
-
Nested: i18n_json-style
profileTitle— flat keys word-camelCased. - pascal → const FlattenKeyStyle
-
Nested:
ProfileTitle— flat keys word-PascalCased. - snake → const FlattenKeyStyle
-
Nested:
profile_title— flat keys word-snake_cased. - kebab → const FlattenKeyStyle
-
Nested:
profile-title— flat keys word-kebab-cased.
Properties
- configName → String
-
Available on FlattenKeyStyle, provided by the FlattenKeyStyleParsing extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FlattenKeyStyle> - A constant List of the values in this enum, in order of their declaration.